@@ -99,7 +99,7 @@ class ConfigWorkRequirement:
     wr_name: Optional[str] = None
 
 
-CR_BATCH_SIZE = 2000
+CR_BATCH_SIZE_DEFAULT = 10000
 
 
 @dataclass
@@ -107,11 +107,12 @@ class ConfigWorkerPool:
     asc_all_nodes_inactive: Optional[float] = None
     asc_all_workers_released: Optional[float] = None
     asc_node_action_failed: Optional[float] = None
+    asc_no_registered_workers: Optional[bool] = None
     asc_unclaimed_after_startup: Optional[float] = None
     auto_scaling_idle_delay: float = 10  # Deprecated
     auto_shutdown: bool = True
     auto_shutdown_delay: float = 10
-    compute_requirement_batch_size: int = CR_BATCH_SIZE
+    compute_requirement_batch_size: int = CR_BATCH_SIZE_DEFAULT
     images_id: Optional[str] = (None,)
     instance_tags: Optional[Dict] = None
     maintainInstanceCount: bool = False  # Only for yd-instantiate
@@ -125,6 +126,7 @@ class ConfigWorkerPool:
     template_id: Optional[str] = None
     user_data: Optional[str] = None
     user_data_file: Optional[str] = None
+    user_data_files: Optional[List[str]] = None
     worker_pool_data_file: Optional[str] = None
     worker_tag: Optional[str] = None
     workers_per_vcpu: Optional[int] = None
@@ -212,6 +214,10 @@ def load_config_common() -> ConfigCommon:
         # substitutions for the items in its dictionary each time it's
         # called
         add_substitutions(subs={URL: url})
+        key = substitute_variable_str(common_section[KEY])
+        add_substitutions(subs={KEY: key})
+        secret = substitute_variable_str(common_section[SECRET])
+        add_substitutions(subs={SECRET: secret})
         namespace = substitute_variable_str(common_section[NAMESPACE])
         add_substitutions(subs={NAMESPACE: namespace})
         name_tag = substitute_variable_str(common_section[NAME_TAG])
@@ -219,8 +225,8 @@ def load_config_common() -> ConfigCommon:
 
         return ConfigCommon(
             # Required
-            key=substitute_variable_str(common_section[KEY]),
-            secret=substitute_variable_str(common_section[SECRET]),
+            key=key,
+            secret=secret,
             namespace=namespace,
             name_tag=name_tag,
             # Optional
@@ -375,6 +381,7 @@ def load_config_worker_pool() -> Optional[ConfigWorkerPool]:
             asc_all_nodes_inactive=wp_section.get(ASC_ALL_NODES_INACTIVE, None),
             asc_all_workers_released=wp_section.get(ASC_ALL_WORKERS_RELEASED, None),
             asc_node_action_failed=wp_section.get(ASC_NODE_ACTION_FAILED, None),
+            asc_no_registered_workers=wp_section.get(ASC_NO_REGISTERED_WORKERS, None),
             asc_unclaimed_after_startup=wp_section.get(
                 ASC_UNCLAIMED_AFTER_STARTUP, None
             ),
@@ -382,7 +389,7 @@ def load_config_worker_pool() -> Optional[ConfigWorkerPool]:
             auto_shutdown=wp_section.get(AUTO_SHUTDOWN, True),
             auto_shutdown_delay=wp_section.get(AUTO_SHUTDOWN_DELAY, 10),
             compute_requirement_batch_size=wp_section.get(
-                COMPUTE_REQUIREMENT_BATCH_SIZE, CR_BATCH_SIZE
+                COMPUTE_REQUIREMENT_BATCH_SIZE, CR_BATCH_SIZE_DEFAULT
             ),
             images_id=wp_section.get(IMAGES_ID, None),
             instance_tags=wp_section.get(INSTANCE_TAGS, None),
@@ -403,6 +410,7 @@ def load_config_worker_pool() -> Optional[ConfigWorkerPool]:
             template_id=wp_section.get(TEMPLATE_ID, None),
             user_data=wp_section.get(USERDATA, None),
             user_data_file=wp_section.get(USERDATAFILE, None),
+            user_data_files=wp_section.get(USERDATAFILES, None),
             worker_pool_data_file=worker_pool_data_file,
             worker_tag=worker_tag,
             workers_per_vcpu=wp_section.get(WORKERS_PER_VCPU, None),
